AdReport class

==================================================================== Ad Report Models

Ad Report Model - ราานการเล่นโฆษณา

Constructors

AdReport({required String adBlockId, required int duration, required String status, required List<AdPlaybackInfo> playbackInfo, String? errorMessage, DateTime? timestamp})

Properties

adBlockId String
final
duration int
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
playbackInfo List<AdPlaybackInfo>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
แปลงเป็น JSON
toJsonString() String
แปลงเป็น JSON String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited